@@ -107,7 +107,6 @@ func TestWithArchDist(t *testing.T) {
 		conditions,
 		statuses, t)
 
-
 }
 
 func TestWithArch(t *testing.T) {
@@ -604,7 +603,6 @@ func TestImageStreamErrorRetry(t *testing.T) {
 		}
 	}
 
-
 	h.processImageStreamWatchEvent(is, false)
 
 	if util.ConditionTrue(cfg, v1.ImportImageErrorsExist) {
@@ -722,6 +720,25 @@ func TestCreateDeleteSecretAfterCR(t *testing.T) {
 
 }
 
+func TestBootstrapRemovedStillHaveSecret(t *testing.T) {
+	h, cfg, event := setup()
+	// mimic result if we bootstrapped as removed
+	cfg.Spec.ManagementState = operatorsv1api.Removed
+	cfg.Status.Version = h.version
+	event.Object = &corev1.Secret{
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      coreosPullSecretName,
+			Namespace: coreosPullSecretNamespace,
+		},
+	}
+	h.secretclientwrapper.(*fakeSecretClientWrapper).err = nil
+	h.Handle(event)
+	importCred := util.Condition(cfg, v1.ImportCredentialsExist)
+	if importCred.Status != corev1.ConditionTrue {
+		t.Fatalf("import creds false: %#v", cfg)
+	}
+}
+
 func setup() (Handler, *v1.Config, util.Event) {
 	h := NewTestHandler()
 	cfg, _ := h.CreateDefaultResourceIfNeeded(nil)
@@ -790,6 +807,80 @@ func TestSecretAPIError(t *testing.T) {
 	validate(true, err, "", cfg, conditions, statuses, t)
 }
 
+func TestTemplateRemovedFromPayload(t *testing.T) {
+	h, _, _ := setup()
+	mimic(&h, x86OCPContentRootDir)
+
+	_, filePath, doUpsert, updateCfgOnly, err := h.prepSamplesWatchEvent("template", "no-longer-exists", map[string]string{}, false)
+	switch {
+	case len(filePath) > 0:
+		t.Fatalf("should not have returned a file path")
+	case doUpsert:
+		t.Fatalf("do upsert should not be true")
+	case updateCfgOnly:
+		t.Fatalf("update cfg only should not be true")
+	case err != nil:
+		t.Fatalf("got unexpected err %s", err.Error())
+	}
+}
+
+func TestImageStreamRemovedFromPayloadWithProgressingErrors(t *testing.T) {
+	h, cfg, _ := setup()
+	mimic(&h, x86OCPContentRootDir)
+	progressing := util.Condition(cfg, v1.ImageChangesInProgress)
+	progressing.Reason = "foo "
+	errors := util.Condition(cfg, v1.ImportImageErrorsExist)
+	errors.Reason = "bar "
+	util.ConditionUpdate(cfg, progressing)
+	util.ConditionUpdate(cfg, errors)
+	fakefile := h.Filefinder.(*fakeResourceFileLister)
+	fakefile.files = map[string][]fakeFileInfo{}
+	tagVersion := int64(1)
+	is := &imagev1.ImageStream{
+		ObjectMeta: metav1.ObjectMeta{
+			Name: "foo",
+			Annotations: map[string]string{
+				v1.SamplesVersionAnnotation: h.version,
+			},
+		},
+		Spec: imagev1.ImageStreamSpec{
+			Tags: []imagev1.TagReference{
+				{
+					Name:       "foo",
+					Generation: &tagVersion,
+				},
+			},
+		},
+		Status: imagev1.ImageStreamStatus{
+			Tags: []imagev1.NamedTagEventList{
+				{
+					Tag: "foo",
+					Items: []imagev1.TagEvent{
+						{
+							Generation: tagVersion,
+						},
+					},
+				},
+			},
+		},
+	}
+	err := h.processImageStreamWatchEvent(is, false)
+	if err != nil {
+		t.Fatal(err)
+	}
+	progressing = util.Condition(cfg, v1.ImageChangesInProgress)
+	if strings.Contains(progressing.Reason, "foo") {
+		t.Fatal("progressing still has foo after it was no longer in payload")
+	}
+	is.Name = "bar"
+	err = h.processImageStreamWatchEvent(is, false)
+	errors = util.Condition(cfg, v1.ImportImageErrorsExist)
+	if strings.Contains(errors.Reason, "bar") {
+		t.Fatal("import errors still has bar after it was no longer in payload")
+	}
+
+}
+
 func TestImageGetError(t *testing.T) {
 	errors := []error{
 		fmt.Errorf("getstreamerror"),
@@ -1366,7 +1457,6 @@ func validate(succeed bool, err error, errstr string, cfg *v1.Config, statuses [
 	validateArchOverride(succeed, err, errstr, cfg, statuses, conditions, t, runtime.GOARCH)
 }
 
-
 func NewTestHandler() Handler {
 	h := Handler{}
 
